diff scripts/plot/subplot.m @ 5214:eecc24b92d97

[project @ 2005-03-16 17:14:12 by jwe]
author jwe
date Wed, 16 Mar 2005 17:14:12 +0000
parents 55db663c15ce
children 32c569794216
line wrap: on
line diff
--- a/scripts/plot/subplot.m	Wed Mar 16 05:34:27 2005 +0000
+++ b/scripts/plot/subplot.m	Wed Mar 16 17:14:12 2005 +0000
@@ -24,7 +24,7 @@
 ## given by index (there are @var{cols} by @var{rows} subwindows).
 ##
 ## The global variable @var{__multiplot_scale__} should be used when the
 ## command @code{gset size xsize, ysize} has been used prior to calling
 ## @code{subplot}.
 ##
 ## The value of @var{__multiplot_scale__} should be a vector with two
@@ -157,9 +157,9 @@
 
       gnuplot_command_replot = "cle;rep";
 
-      gset multiplot;
+      __gset__ multiplot;
 
-      eval (sprintf ("gset size %g, %g", __multiplot_xsize__,
+      eval (sprintf ("__gset__ size %g, %g", __multiplot_xsize__,
                      __multiplot_ysize__));
     endif
 
@@ -175,7 +175,7 @@
     xo = (xp - 1.0) * __multiplot_xsize__;
     yo = (rows - yp) * __multiplot_ysize__;
 
-    eval (sprintf ("gset origin %g, %g", xo, yo));
+    eval (sprintf ("__gset__ origin %g, %g", xo, yo));
 
   endif
@@ -24,7 +24,7 @@
 ##
 ## The global variable @var{__multiplot_scale__} should be used when the
-## command @code{gset size xsize, ysize} has been used prior to calling
+## command @code{__gset__ size xsize, ysize} has been used prior to calling
 ## @code{subplot}.
 ##